
# ----------------------------------------------------------------------------
# Licensed Materials - Property of IBM
#  
# IBM Websphere Adapter for Ariba Buyer Version 2.0, 5724-B89
#
# (C) Copyright IBM Corp. 2002 All Rights Reserved.
#
# US Government Users Restricted Rights - Use, duplication or
# disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
#
# installation script for WAAB eFix 1
# JZ@08/2002
# ----------------------------------------------------------------------------



#------------------------------------------------------------------------------------------------------------------------------------------
#
#what does this script do?
#
#------------------------------------------------------------------------------------------------------------------------------------------
#
#<WAAB_efix.pl - backup files to be modified, setup and invoke install_efix.java>
#2.	WAAB _efix.pl will prompt user for installation directories
#  a.	WAAB Installation directory 				<WAAB_dir>
#  b.	Efix directory (don't prompt if we can figure this out)	<EFix_dir>
#  c.	Version of MA88 > 5.2.0.0 (y/n) - translate to true/false	<MA88_Patch>
#3.	Create backup and temp directories
#  a.	<WAAB_dir>\backup\WAAB_<TIMESTAMP>     	<WAAB_backup_dir>
#b.	<WAAB_dir>\temp					<WAAB_temp_dir>
#4.	Backup config.pl
#  a.	copy <Buyer_dir>\channels\MQSeries\config.pl to <WAAB_backup_dir>\channels\MQSeries\cofing.pl
#5.	Replace <EFix_dir>\channels\MQSeries\config.pl to <Buyer_dir>\channels\MQSeries\config.pl
#6.	Generates mapping files in temp directory
#  a.	config.pl -verifyMap <WAAB_temp_dir>
#7.	Backup mapping template files
#  a.	copy <Buyer_dir>\channels\MQSeries\*.txt to <WAAB_backup_dir>\channels\MQSeries
#8.	Backup files which could be updated by Java program
#  a.	copy <WAAB_dir>\data\aqmconfig.xml to <WAAB_backup_dir>\data
#  b.	copy <Buyer_dir>\classpath.txt to to <WAAB_backup_dir>
#<install_efix.java - check version, validate existing configuration and mapping>
#9.	Run java program
#  a.	checkVersion() - compare text of versionMessages.properties with "EPV0001=WebSphere Adapter for Ariba Buyer V2.0.0.1 Build 08 (WAAB_05_20_02)"
#  b.	checkClasspath()- if <MA88_Patch>
#  i.	classpath.txt  should include com.ibm.connector.jar
#  ii.	classpath.txt  should NOT include com.ibm.iiop.jar 
#  iii.	CLASSPATH environment variable should include com.ibm.connector.jar and com.ibm.jta.jar
#  c.	checkAqmconfig()  - check <WAAB_dir>\data\aqmconfig.xml for duplicate queue names in AribaBuyerImport
#  i.	get the <epicreceivemqppqueue> value of epicappid="AribaBuyerImport" epicbodycategory="CSV" epicbodytype="DEFAULT"
#  ii.	check value against all other <epicreceivemqppqueue> values in epicappid="AribaBuyerImport"  
#  iii.	if match found 
#  1.	if epicbodycategory="OAG" and epicbodytype="CONFIRM_BOD_003"
#a.	save file in <WAAB_backup_dir>\data\  
#b.	remove stanza from file
#c.	save file in <WAAB_dir>\data
#2.	notify user that multiple entries can not point to the same queue as CSV/DEFAULT, specify possible actions and EXIT
#iv.	if no match found, continue
#d.	checkMapping() - compare generated mapping files with existing mapping files
#i.	compare all MQCSVMapping.xml files in <WAAB_temp_dir> with <WAAB_dir>\data\variants
#ii.	if comparison fails, rename <WAAB_temp_dir>\data\variants to <WAAB_temp_dir>\data\variants <TIMESTAMP>
#<WAAB_efix.pl - copy new class files, modify mapping, update version>
#10.	Copy class files which will be modified to <WAAB_backup_dir>\bin
#  a.	\com\ibm\bpac\aribabuyer\csvadapter\MQCSVAdapter.class
#  b.	\com\ibm\bpac\aribabuyer\csvadapter\MQCSVFileData.class
#  c.	\com\ibm\bpac\aribabuyer\util\MQFileUtil.class
#  d.	\com\ibm\bpac\aribabuyer\outbound\MQAribaObjtoXML.class
#  e.	\com\ibm\bpac\aribabuyer\inbound\MQXMLtoAribaObj.class
#11.	Copy the new class files into <WAAB_dir>\bin
#  a.	\com\ibm\bpac\aribabuyer\csvadapter\MQCSVAdapter.class
#  b.	\com\ibm\bpac\aribabuyer\csvadapter\MQCSVFileData.class
#  c.	\com\ibm\bpac\aribabuyer\util\MQFileUtil.class
#  d.	\com\ibm\bpac\aribabuyer\outbound\MQAribaObjtoXML.class
#  e.	\com\ibm\bpac\aribabuyer\inbound\MQXMLtoAribaObj.class
#12.	Append new mapping templates files with existing mapping template files
#  a.	append csvEventMapPart.txt_append to csvEventMapPart.txt in \CoreServer\channels\MQSeries
#  b.	copy plainEventReaderPar.txt_append to plainEventReaderPar.txt in \CoreServer\channels\MQSeries
#  c.	copy supplierdirectEventReaderPar.txt_append to supplierdirectEventReaderPar.txt in \CoreServer\channels\MQSeries
#  d.	append csvEventReaderPar.txt_append to csvEventReaderPar.txt in \CoreServer\channels\MQSeries
#  e.	copy sapEventReaderPar.txt_append to sapEventReaderPar.txt in \CoreServer\channels\MQSeries
#  f.	copy all _append files to <WAAB_dir>\samples\aribaBuyer\mapping_names and  <WAAB_dir>\samples\aribaBuyer\mapping_positions
#13.	Move existing mapping files to backup directory
#  a.	Move <WAAB_dir>\data\variants to <WAAB_backup_dir>\data\variants
#14.    change  SAPEventMapPart.txt to  sapEventMapPart.txt in the following three places:
#         - <Ariba Install dir>\CoreServer\channels\MQSeries\
#         - <WAAB Install dir>\samples\aribaBuyer\mapping_names
#         - <WAAB Install dir>\samples\aribaBuyer\mapping_positions
#15.	Generates new mapping files
#  a.	run config.pl -mapping
#16.	Copy versionMessages.properties to <WAAB_dir>\bin\com\ibm\bpac\aribabuyer\VersionMessages.properties (overwrite)
#
#17.	Notify user of success
# ------------------------------------------------------------------------------------------------------------------------------------------





use Ariba::Config ();
use Ariba::TableEdit ();
use Ariba::Util ();
use File::Basename;

sub main ()
{
   my  $aribaBuyerInstallDir = $ARGV[0];
   $aribaBuyerInstallDir = convertSlashes($aribaBuyerInstallDir);


   print "\n";
   print "****************************************************************\n";
   print "*                                                              *\n";
   print "*    eFix 1 for WebSphere Adapter For Ariba Buyer (WAAB)       *\n";
   print "*                                                              *\n";
   print "****************************************************************\n";
   
   print "\nYour Ariba CoreServer installation directory is $aribaBuyerInstallDir. \n";
   
   #Prompt user for WAAB installaiton directory
   print "\nPlease enter the full path of your WAAB installation directory:\n";   #waab dir
   chop($waabInstallDir = <STDIN>);
   while (!-d $waabInstallDir) {
      print "The WAAB installation directory doesn't exist,  please re-enter it:\n";
      chop($waabInstallDir = <STDIN>);
   }
   $waabInstallDir = convertSlashes($waabInstallDir);

   print "\nYour WAAB installation directory is $waabInstallDir. \n";
   #logfile ($logFileName, "Your WAAB installation directory is $waabInstallDir.");

     
   # Prompt user for Ariba Buyer installaiton directory
   print "\nPlease enter the full path where you uncompressed the eFix package:\n";    #ariba buyer dir
   chop($efixDir = <STDIN>);
   while (!-d $efixDir) {
      print "This directory doesn't exist,  please re-enter it:\n";
      chop($efixDir = <STDIN>);
   }

   $efixDir = convertSlashes($efixDir);

   #log file 
   $logFileName = "$efixDir/waab_eFix1.log";
   logfile ($logFileName, "WAAB eFix1 installation log:");
   logfile ($logFileName,  "Your Ariba CoreServer installation directory is $aribaBuyerInstallDir.");
   logfile ($logFileName, "Your WAAB installation directory is $waabInstallDir.");
   
   print "\nYour eFix directory is $efixDir. \n";
   logfile ($logFileName, "Your Efix directory is $efixDir."); 

   #step 3  Create backup and temp directories
   #($waabBackupRef, $waabTempRef) = createBakeupTempDirs ();
   ($waabBackupRef) = createBakeupTempDirs ();

   #step 4a copy <Buyer_dir>\channels\MQSeries\config.pl to <WAAB_backup_dir>\channels\MQSeries\cofing.pl   
   copyConfigFileToWaabBackup ($aribaBuyerInstallDir, $waabBackupRef);

   #step 5  Replace <EFix_dir>\channels\MQSeries\config.pl to <Buyer_dir>\channels\MQSeries\config.pl
   copyConfigFileToAribaBuyer ($efixDir, $aribaBuyerInstallDir);

   #setup unix environment
   $os = $^O;
   print "\nYour system is $os\n";
   logfile ($logFileName, "Your system is $os.");

   if  (($os eq 'solaris') || ($os eq 'aix') || ($os eq 'hpux') || ($os eq 'linux') )
   {
      $ENV{'AQMSETUPFILE'} = $waabInstallDir."/data/aqmsetup";
   }

   #step 6  Generates mapping files in temp directory
   # Don't do this ***PKP 9/30/02***
   #generateMappingFiles ($aribaBuyerInstallDir, $waabTempRef, $efixDir, $waabInstallDir);

   #step 7  Backup mapping template files
   #backupMappingTemplateFiles ($aribaBuyerInstallDir, $waabBackupRef);

   #Step 8a copy <WAAB_dir>\data\aqmconfig.xml to <WAAB_backup_dir>\data
   backupXMLFiles ($waabInstallDir, $waabBackupRef);

   #step 8b copy <Buyer_dir>\classpath.txt to to <WAAB_backup_dir>
   backupClassTxtFiles ($aribaBuyerInstallDir, $waabBackupRef);

   #step 9 Run java program
   runJavaInstallProgram ($waabInstallDir, $aribaBuyerInstallDir);

   #Step 10 Copy class files which will be modified to <WAAB_backup_dir>\bin
   copyClassFilesToWaab ($waabInstallDir, $waabBackupRef); 

   #step 11 Copy the new class files into <WAAB_dir>\bin
   copyNewClassFilesToWaab ($efixDir, $waabInstallDir); 

   #Append new mapping templates files with existing mapping template files
   #step 12a and 12d
   #appendMappingFiles ($efixDir, $aribaBuyerInstallDir);

   #step 12b, 12c, 12e
   #renameAppendFiles ($efixDir, $aribaBuyerInstallDir);

   #step 12f
   #copyAllAppendFilesToWaab ($efixDir, $waabInstallDir);

   #step 13 Move existing mapping files to backup directory
   #moveMappingFilesToBackupDir ($waabInstallDir, $waabBackupRef);

   #step 14 change  SAPEventMapPart.txt to  sapEventMapPart.txt 
   #changeSAPEventMapPart($aribaBuyerInstallDir, $waabInstallDir);

   #Step 15 Generates new mapping files
   #generateNewMappingFiles ($aribaBuyerInstallDir, $efixDir);

   #step 16 Copy versionMessages.properties 
   copyVersionMessage ($efixDir, $waabInstallDir);

   print "\nThe WAAB eFix 1 installation is complete.\n";
   logfile ($logFileName, "The WAAB eFix 1 installation is complete.");

}

sub usage ()
{
   print "\nusage: perl waab_efix1_installation\n";

}

sub logfile  {
   my ($fileName, $logString) = @_;

   open(FILE,  ">>$fileName");
   $localtime = localtime;
   print FILE "\n$localtime  ";
   print FILE $logString;
   close (FILE);
}

sub convertSlashes() 
{
   my ($str) = @_;
   $newStr = $str;
   $newStr =~ s/\\/\//g; 
   return $newStr;
}

sub convertSlashestoBackward() 
{
   my ($str) = @_;
   $newStr = $str;
   #$newStr =~ s/\\/\//g; 
   $newStr =~ s/\//\\/g;
   print "\nnewstring = $newStr\n";
   return $newStr;
}

#3a, 3b	Create backup and temp directories
sub createBakeupTempDirs () 
{

   #Create backup  directories for waab
   if (-d $waabInstallDir) {

      print "\nCreating the backup directories...\n";

      $localtime = localtime;
      $localtime =~ s/\s//g; #remove space;
      $localtime =~ s/://g; #remove :;

      $waabBackupDir = $waabInstallDir . "/backup/WAAB_" . $localtime;
      print "\nCreating a WAAB backup directory $waabBackupDir...\n";
      Ariba::Util::safeMkDir($waabBackupDir);
      if (-d $waabBackupDir) {
         print "\nSuccessfully created WAAB backup directory $waabBackupDir\n";
         logfile ($logFileName, "Successfully created WAAB backup directory $waabBackupDir.");
      }
      else   {
         print "\nFail to create WAAB backup directory $waabBackupDir\n";
         logfile ($logFileName, "fail to create WAAB backup directory $waabBackupDir.");
         exit (1);
      }
   }

   #Create  temp directories for waab temp
   if (-d $waabInstallDir) {

      print "\nCreating the temp directories...\n";
      $waabTempDir = $waabInstallDir . "/temp";

      print "Creating a WAAB temp directory $waabTempDir...\n";
      Ariba::Util::safeMkDir($waabTempDir);
      if (-d $waabTempDir) {
           print "\nSuccessfully created WAAB temp directory $waabTempDir\n";
           logfile ($logFileName, "Successfully created WAAB temp directory $waabTempDir.");      
      }
      else   {
         print "\nFail to create WAAB temp directory $waabTempDir\n";
         logfile ($logFileName, "fail to create WAAB temp directory $waabTempDir."); 
         exit (1);
      }
   }
   return ($waabBackupDir, $waabTempDir);
}

#4a. copy <Buyer_dir>\channels\MQSeries\config.pl to <WAAB_backup_dir>\channels\MQSeries\cofing.pl
sub copyConfigFileToWaabBackup () 
{
   
   my ($aribaBuyerInstallDir, $waabBackupDir) = @_;
   $aribaBuyerConfigPl = $aribaBuyerInstallDir . "/channels/MQSeries/config.pl";

   $waabBackupChannelsMqSeriesDir = $waabBackupDir . "/channels/MQSeries";

   Ariba::Util::safeMkDir($waabBackupChannelsMqSeriesDir);
   $waabBackupConfigPl = $waabBackupChannelsMqSeriesDir .  "/config.pl";

   Ariba::Util::safeCopy($aribaBuyerConfigPl, $waabBackupConfigPl);
   print "\nCopy $aribaBuyerConfigPl to $waabBackupConfigPl.\n";
   logfile ($logFileName, "Copy $aribaBuyerConfigPl to $waabBackupConfigPl.");
}

#5 Replace <EFix_dir>\channels\MQSeries\config.pl to <Buyer_dir>\channels\MQSeries\config.pl
sub copyConfigFileToAribaBuyer ()
{
   my ($efixDir, $aribaBuyerInstallDir) = @_;
   $efixConfigPl = $efixDir . "/channels/MQSeries/config.pl";

   $aribaConfigPl = $aribaBuyerInstallDir .  "/channels/MQSeries/config.pl";

   Ariba::Util::safeCopy($efixConfigPl, $aribaConfigPl);
   print "\nCopy $efixConfigPl to $aribaConfigPl.\n";
   logfile ($logFileName, "Copy $efixConfigPl to $aribaConfigPl.");

}


#6  Generates mapping files in temp directory
sub generateMappingFiles ()
{
   my ($aribaBuyerInstallDir, $waabTempDir, $efixDir, $waabInstallDir) = @_;
   print "\nGenerating the mapping template files...\n";
   chdir ($aribaBuyerInstallDir);
   Ariba::Util::safeSystem("runperl ./channels/MQSeries/config.pl -verifyMap $waabInstallDir");

   chdir ($efixDir);
   print "\nRun 'runperl ./channels/MQSeries/config.pl -verifyMap $waabInstallDir'\n";
   logfile ($logFileName, "Run 'runperl ./channels/MQSeries/config.pl -verifyMap $waabInstallDir'");

}

  
#7 Backup mapping template files
sub backupMappingTemplateFiles ()
{
   my ($aribaBuyerInstallDir, $waabBackupDir) = @_;

   $fromDir = $aribaBuyerInstallDir . "/channels/MQSeries/";

   $toDir = $waabBackupDir . "/channels/MQSeries/";

   Ariba::Util::safeMkDir($toDir);

   $fromFile1 = $fromDir . "csvEventMapPart.txt";
   $toFile1 =  $toDir . "csvEventMapPart.txt";
   if (-f $fromFile1)
   {
      Ariba::Util::safeCopy($fromFile1, $toFile1);
      print "\nCopying $fromFile1 to $toFile1...\n";
      logfile ($logFileName, "Copying $fromFile1 to $toFile1");

   }

   $fromFile2 = $fromDir . "csvEventReaderPar.txt";
   $toFile2 =  $toDir . "csvEventReaderPar.txt";
   if (-f $fromFile2) 
   {
      Ariba::Util::safeCopy($fromFile2, $toFile2);
      print "\nCopying $fromFile2 to $toFile2...\n";
      logfile ($logFileName, "Copying $fromFile2 to $toFile2");

   }
}

#8a  copy <WAAB_dir>\data\aqmconfig.xml to <WAAB_backup_dir>\data
sub backupXMLFiles ()
{
   #backup the xml files
   my ($waabInstallDir, $waabBackupDir) = @_;
   $waabDataDir = $waabInstallDir . "/data";
   if (!-d $waabDataDir) 
   {
      Ariba::Util::safeMkDir($waabDataDir);
   }

   $waabBackupDataDir = $waabBackupDir . "/data";

   if (!-d $waabBackupDataDir) 
   {
      Ariba::Util::safeMkDir($waabBackupDataDir);
   }
   $aqmconfigFileFrom =  $waabDataDir . "/aqmconfig.xml";
   $aqmconfigFileTo =  $waabBackupDataDir . "/aqmconfig.xml";

   Ariba::Util::safeCopy($aqmconfigFileFrom, $aqmconfigFileTo);
   print "\nCopy $aqmconfigFileFrom to $aqmconfigFileTo.\n";
   logfile ($logFileName, "Copy $aqmconfigFileFrom to $aqmconfigFileTo.");

}

#8b copy <Buyer_dir>\classpath.txt to to <WAAB_backup_dir>
sub backupClassTxtFiles () 
{
   #backup the class text files
   my ($aribaBuyerInstallDir, $waabBackupDir) = @_;
   $classFileFrom = $aribaBuyerInstallDir . "/classpath.txt";
   $classFileTo = $waabBackupDir . "/classpath.txt";

   Ariba::Util::safeCopy($classFileFrom, $classFileTo);
   print "\nCopy $classFileFrom to $classFileTo.\n";
   logfile ($logFileName, "Copy $classFileFrom to $classFileTo.");
 
}

#9 Run java program
sub runJavaInstallProgram ()
{
   #Run java install program: install_efix
   my ($waabInstallDir, $aribaBuyerInstallDir) = @_;

   print "\nRunning Java install_efix...\n";
   print "\nIs your MA88 version is greater than 5.2.0.0? [Y/N]\n";
   chop($ma88Version = <STDIN>);
   $os = $^O;
   
   if (($ma88Version eq 'Y') || ($ma88Version eq 'y')) 
   {
      $ma88Version = "true";
   }
   else
   {
      $ma88Version = "false";
   }

   $classpath = $ENV{'CLASSPATH'}; 

   chdir ($efixDir);
   logfile ($logFileName, "Run 'java install_efix $waabInstallDir $aribaBuyerInstallDir $ma88Version'\n");   
   Ariba::Util::safeSystem("java install_efix \"$waabInstallDir\" \"$aribaBuyerInstallDir\" $ma88Version \"$classpath\"");
}

#10 Copy class files which will be modified to <WAAB_backup_dir>\bin
sub copyClassFilesToWaab () 
{
   #Copy class files which will be modified to waab backup dir
   print "\nCopy class files which will be modified to waab backup directory...\n";
   my ($waabInstallDir, $waabBackupDir) = @_;

   $waabBinDir = $waabInstallDir . "/bin";

   if (!-d $waabBinDir) 
   {
      Ariba::Util::safeMkDir($waabBinDir);
   }
   
   $classFileToDir1 =  $waabBackupDir . "/bin/com/ibm/bpac/aribabuyer/csvadapter";
   if (!-d $classFileToDir1) 
   {
      Ariba::Util::safeMkDir($classFileToDir1);
   }
   $classFileFrom1 = $waabBinDir . "/com/ibm/bpac/aribabuyer/csvadapter/MQCSVAdapter.class";

   $classFileT1 = $classFileToDir1 . "/MQCSVAdapter.class";

   Ariba::Util::safeCopy($classFileFrom1, $classFileT1);
   print "\nCopy $classFileFrom1 to $classFileT1.\n";
   logfile ($logFileName, "copy $classFileFrom1 to $classFileT1.");


   $classFileToDir2 =  $waabBackupDir . "/bin/com/ibm/bpac/aribabuyer/csvadapter";

   if (!-d $classFileToDir2) 
   {
      Ariba::Util::safeMkDir($classFileToDir2);
   }
   $classFileFrom2 = $waabBinDir . "/com/ibm/bpac/aribabuyer/csvadapter/MQCSVFileData.class";

   $classFileT2 = $classFileToDir2 . "/MQCSVFileData.class";

   Ariba::Util::safeCopy($classFileFrom2, $classFileT2);
   print "\nCopy $classFileFrom2 to $classFileT2.\n";
   logfile ($logFileName, "copy $classFileFrom2 to $classFileT2.");

   $classFileToDir3 =  $waabBackupDir . "/bin/com/ibm/bpac/aribabuyer/util";

   if (!-d $classFileToDir3) 
   {
     Ariba::Util::safeMkDir($classFileToDir3);
   }
   $classFileFrom3 = $waabBinDir . "/com/ibm/bpac/aribabuyer/util/MQFileUtil.class";

   $classFileT3 = $classFileToDir3 . "/MQFileUtil.class";

   Ariba::Util::safeCopy($classFileFrom3, $classFileT3);
   print "\nCopy $classFileFrom3 to $classFileT3.\n";
   logfile ($logFileName, "copy $classFileFrom3 to $classFileT3.");

   $classFileToDir4 =  $waabBackupDir . "/bin/com/ibm/bpac/aribabuyer/outbound";

   if (!-d $classFileToDir4) 
   {
    Ariba::Util::safeMkDir($classFileToDir4);
   }
   $classFileFrom4 = $waabBinDir . "/com/ibm/bpac/aribabuyer/outbound/MQAribaObjtoXML.class";

   $classFileT4 = $classFileToDir4 . "/MQAribaObjtoXML.class";

   Ariba::Util::safeCopy($classFileFrom4, $classFileT4);
   print "\nCopy $classFileFrom4 to $classFileT4.\n";
   logfile ($logFileName, "copy $classFileFrom4 to $classFileT4.");

   $classFileToDir5 =  $waabBackupDir . "/bin/com/ibm/bpac/aribabuyer/inbound";

   $classFileToDir5 =  $waabBackupDir . "/bin/com/ibm/bpac/aribabuyer/inbound";

   if (!-d $classFileToDir5) 
   {
    Ariba::Util::safeMkDir($classFileToDir5);
   }
   $classFileFrom5 = $waabBinDir . "/com/ibm/bpac/aribabuyer/inbound/MQXMLtoAribaObj.class";

   $classFileT5 = $classFileToDir5 ."/MQXMLtoAribaObj.class";

   Ariba::Util::safeCopy($classFileFrom5, $classFileT5);
   print "\nCopy $classFileFrom5 to $classFileT5.\n";
   logfile ($logFileName, "copy $classFileFrom5 to $classFileT5.");
}

#11 Copy the new class files into <WAAB_dir>\bin
sub copyNewClassFilesToWaab () 
{
   #Copy the new class files into waab\bin
   print "\nCopy the new class file into waab bin...\n";
   my ($efixDir, $waabInstallDir) = @_;

   $classFileFromEfix1 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/csvadapter/MQCSVAdapter.class";

   $classFileTWaab1 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/csvadapter/MQCSVAdapter.class";

   Ariba::Util::safeCopy($classFileFromEfix1, $classFileTWaab1);
   print "\nCopy $classFileFromEfix1 to $classFileTWaab1.\n";
   logfile ($logFileName, "copy $classFileFromEfix1 to $classFileTWaab1.");


   $classFileFromEfix2 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/csvadapter/MQCSVFileData.class";

   $classFileTWaab2 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/csvadapter/MQCSVFileData.class";
   
   Ariba::Util::safeCopy($classFileFromEfix2, $classFileTWaab2);
   print "\nCopy $classFileFromEfix2 to $classFileTWaab2.\n";
   logfile ($logFileName, "copy $classFileFromEfix2 to $classFileTWaab2.");

   $classFileFromEfix3 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/util/MQFileUtil.class";
   $classFileTWaab3 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/util/MQFileUtil.class";
   Ariba::Util::safeCopy($classFileFromEfix3, $classFileTWaab3);
   print "\nCopy $classFileFromEfix3 to $classFileTWaab3.\n";
   logfile ($logFileName, "copy $classFileFromEfix3 to $classFileTWaab3.");


   $classFileFromEfix4 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/outbound/MQAribaObjtoXML.class";
   $classFileTWaab4 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/outbound/MQAribaObjtoXML.class";
   Ariba::Util::safeCopy($classFileFromEfix4, $classFileTWaab4);
   print "\nCopy $classFileFromEfix4 to $classFileTWaab4.\n";
   logfile ($logFileName, "copy $classFileFromEfix4 to $classFileTWaab4.");


   $classFileFromEfix5 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/inbound/MQXMLtoAribaObj.class";
   $classFileTWaab5 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/inbound/MQXMLtoAribaObj.class";
   Ariba::Util::safeCopy($classFileFromEfix5, $classFileTWaab5);
   print "\nCopy $classFileFromEfix5 to $classFileTWaab5.\n";
   logfile ($logFileName, "copy $classFileFromEfix5 to $classFileTWaab5.");

   #copy \com\ibm\bpac\aribabuyer\util\MQCSVHashtableFileReader.class
   $classFileFromEfix6 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/util/MQCSVHashtableFileReader.class";
   $classFileTWaab6 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/util/MQCSVHashtableFileReader.class";
   Ariba::Util::safeCopy($classFileFromEfix6, $classFileTWaab6);
   print "\nCopy $classFileFromEfix6 to $classFileTWaab6.\n";
   logfile ($logFileName, "copy $classFileFromEfix6 to $classFileTWaab6.");

   #copy \com\ibm\bpac\aribabuyer\util\MQCSVVectorFileReader.class
   $classFileFromEfix7 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/util/MQCSVVectorFileReader.class";
   $classFileTWaab7 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/util/MQCSVVectorFileReader.class";
   Ariba::Util::safeCopy($classFileFromEfix7, $classFileTWaab7);
   print "\nCopy $classFileFromEfix7 to $classFileTWaab7.\n";
   logfile ($logFileName, "copy $classFileFromEfix7 to $classFileTWaab7.");

   #copy \com\ibm\bpac\aribabuyer\util\MQCSVFileReader.class
   $classFileFromEfix8 = $efixDir .     "/bin/com/ibm/bpac/aribabuyer/util/MQCSVFileReader.class";
   $classFileTWaab8 = $waabInstallDir . "/bin/com/ibm/bpac/aribabuyer/util/MQCSVFileReader.class";
   Ariba::Util::safeCopy($classFileFromEfix8, $classFileTWaab8);
   print "\nCopy $classFileFromEfix8 to $classFileTWaab8.\n";
   logfile ($logFileName, "copy $classFileFromEfix8 to $classFileTWaab8.");
 

}

#12a 12d Append new mapping templates files with existing mapping template files
sub appendMappingFiles () 
{
   #Append new mapping templates files with existing mapping template files
   my ($efixDir, $aribaBuyerInstallDir) = @_;

   print "\nAppending new mapping template files with existing mapping template files...\n";

   $efixAppendFileDir = $efixDir . "/samples/aribaBuyer/mapping_names";

   $appendFrom1 = $efixAppendFileDir . "/csvEventMapPart.txt_append";
   $appendFrom1 = $efixAppendFileDir . "/csvEventMapPart.txt_append";

   print "\nThe first appended file is $appendFrom1\n";
   $appendTo1 = $aribaBuyerInstallDir . "/channels/MQSeries/" . "csvEventMapPart.txt";

   Ariba::Util::appendFile($appendFrom1, $appendTo1);
   logfile ($logFileName, "append $appendFrom1 to $appendTo1.");


   $appendFrom2 = $efixAppendFileDir . "/csvEventReaderPar.txt_append";

   print "\nThe second appended file is $appendFrom2\n";
   $appendTo2 = $aribaBuyerInstallDir . "/channels/MQSeries/" . "csvEventReaderPar.txt";

   Ariba::Util::appendFile($appendFrom2, $appendTo2);
   logfile ($logFileName, "append $appendFrom2 to $appendTo2.");
}

#12b 12c 12e Append new mapping templates files with existing mapping template files
sub  renameAppendFiles ()
{
   #Rename append files
   my ($efixDir, $aribaBuyerInstallDir) = @_;
   print "\nRenaming appending files...\n";
   $efixAppendFileDir = $efixDir . "/samples/aribaBuyer/mapping_names";

   $configDir = $aribaBuyerInstallDir . "/channels/MQSeries";

   $renameFileFrom1 = $efixAppendFileDir . "/plainEventReaderPar.txt_append";

   $renameFileTo1 =  $configDir . "/plainEventReaderPar.txt";

   Ariba::Util::safeCopy($renameFileFrom1, $renameFileTo1);
   print "\nRename $renameFileFrom1 to $renameFileTo1.\n";
   logfile ($logFileName, "rename $renameFileFrom1 to $renameFileTo1.");

   $renameFileFrom2 = $efixAppendFileDir . "/supplierdirectEventReaderPar.txt_append";

   $renameFileTo2 =  $configDir . "/supplierdirectEventReaderPar.txt";

   Ariba::Util::safeCopy($renameFileFrom2, $renameFileTo2);
   print "\nRename $renameFileFrom2 to $renameFileTo2.\n";
   logfile ($logFileName, "rename $renameFileFrom2 to $renameFileTo2.");

   $renameFileFrom3 = $efixAppendFileDir . "/sapEventReaderPar.txt_append";

   $renameFileTo3 = $configDir . "/sapEventReaderPar.txt";

   Ariba::Util::safeCopy($renameFileFrom3, $renameFileTo3);
   print "\nRename $renameFileFrom3 to $renameFileTo3.\n";
   logfile ($logFileName, "rename $renameFileFrom3 to $renameFileTo3.");

}

#12f copy all _append files to <WAAB_dir>\samples\aribaBuyer\mapping_names and  <WAAB_dir>\samples\aribaBuyer\mapping_positions
sub copyAllAppendFilesToWaab ()
{
   #Copy all _append files 
   my ($efixDir, $waabInstallDir) = @_;
   print "\nCopy all append files...\n";

   $waabMappingNameDir = $waabInstallDir . "/samples/aribaBuyer/mapping_names";
   $efixAppendFileNameDir = $efixDir . "/samples/aribaBuyer/mapping_names";

   $appendFrom1 = $efixAppendFileNameDir .  "/csvEventMapPart.txt_append";
   $appendFileCopyTo1 = $waabMappingNameDir .  "/cvsEventMapPart.txt_append";

   Ariba::Util::safeCopy($appendFrom1, $appendFileCopyTo1);
   print "\nCopy $appendFrom1 to $appendFileCopyTo1.\n";
   logfile ($logFileName, "copy $appendFrom1 to $appendFileCopyTo1.");

   $appendFrom2 = $efixAppendFileNameDir .  "/csvEventReaderPar.txt_append";
   $appendFileCopyTo2 = $waabMappingNameDir .  "/csvEventReaderPar.txt_append";

   Ariba::Util::safeCopy($appendFrom2, $appendFileCopyTo2);
   print "\nCopy $appendFrom2 to $appendFileCopyTo2.\n";
   logfile ($logFileName, "copy $appendFrom2 to $appendFileCopyTo2.");

   $appendFrom3 = $efixAppendFileNameDir .  "/plainEventReaderPar.txt_append";
   $appendFileCopyTo3 = $waabMappingNameDir .  "/plainEventReaderPar.txt_append";

   Ariba::Util::safeCopy($appendFrom3, $appendFileCopyTo3);
   print "\nCopy $appendFrom3 to $appendFileCopyTo3.\n";
   logfile ($logFileName, "copy $appendFrom3 to $appendFileCopyTo3.");

   $appendFrom4 = $efixAppendFileNameDir .  "/sapEventReaderPar.txt_append";
   $appendFileCopyTo4 = $waabMappingNameDir . "/sapEventReaderPar.txt_append";

   Ariba::Util::safeCopy($appendFrom4, $appendFileCopyTo4);
   print "\nCopy $appendFrom4 to $appendFileCopyTo4.\n";
   logfile ($logFileName, "copy $appendFrom4 to $appendFileCopyTo4.");

   $appendFrom5 = $efixAppendFileNameDir .  "/supplierdirectEventReaderPar.txt_append";
   $appendFileCopyTo5 = $waabMappingNameDir . "/supplierdirectEventReaderPar.txt_append";

   Ariba::Util::safeCopy($appendFrom5, $appendFileCopyTo5);
   print "\nCopy $appendFrom5 to $appendFileCopyTo5.\n";
   logfile ($logFileName, "copy $appendFrom5 to $appendFileCopyTo5.");

   $waabMappingPositions = $waabInstallDir . "/samples/aribaBuyer/mapping_positions";
   $efixAppendFilePositionsDir =  $efixDir . "/samples/aribaBuyer/mapping_positions";

   $appendFrom6 = $efixAppendFilePositionsDir .  "/csvEventMapPart.txt_append";
   $appendFileCopyTo6 = $waabMappingPositions .  "/cvsEventMapPart.txt_append";

   Ariba::Util::safeCopy($appendFrom6, $appendFileCopyTo6);
   print "\nCopy $appendFrom6 to $appendFileCopyTo6.\n";
   logfile ($logFileName, "copy $appendFrom6 to $appendFileCopyTo6.");

   $appendFrom7 = $efixAppendFilePositionsDir .  "/csvEventReaderPar.txt_append";
   $appendFileCopyTo7 = $waabMappingPositions .  "/csvEventReaderPar.txt_append";

   Ariba::Util::safeCopy($appendFrom7, $appendFileCopyTo7);
   print "\nCopy $appendFrom7 to $appendFileCopyTo7.\n";
   logfile ($logFileName, "copy $appendFrom7 to $appendFileCopyTo7.");

}

#13 Move existing mapping files to backup directory
sub moveMappingFilesToBackupDir () 
{
   #Move existing mapping files to backup directory
   my ($waabInstallDir, $waabBackupDir) = @_;
   print "\nMoving the existing mapping files to backup directory...\n";
   
  $MoveDirFrom = $waabInstallDir . "/data/variants/";
  $MoveDirTo =  $waabBackupDir . "/data/variants/";

   if (!-d $MoveDirFrom) 
   {
      Ariba::Util::safeMkDir($MoveDirFrom);
   }
   if (!-d $MoveDirTo) 
   {
      Ariba::Util::safeMkDir($MoveDirTo);
   }
   $os = $^O;
 
   if ($os eq 'MSWin32')
   {
      $MoveDirFrom =~ s/\//\\/gi;
      $MoveDirTo =~ s/\//\\/gi;

      Ariba::Util::safeSystem("xcopy \"$MoveDirFrom*.*\" \"$MoveDirTo\" /E");
      print "\nxcopy $MoveDirFrom*.* $MoveDirTo.\n";
      logfile ($logFileName, "xcopy $MoveDirFrom*.* $MoveDirTo.");

      $dataDir = $waabInstallDir . "\\data";
      chdir($dataDir);
      Ariba::Util::safeSystem("rd /S /Q variants");
      print "\nRemoved $MoveDirFrom.\n";
      logfile ($logFileName, "removed $MoveDirFrom.");
   }
   else
   {
      Ariba::Util::safeSystem("cp -r $MoveDirFrom $MoveDirTo");
      print "\ncp $MoveDirFrom $MoveDirTo.\n";
      logfile ($logFileName, "cp $MoveDirFrom $MoveDirTo.");
      Ariba::Util::safeSystem("rm -r $MoveDirFrom");
      print "\nRemoved $MoveDirFrom.\n";
      logfile ($logFileName, "removed $MoveDirFrom.");
   }

}


#step 14 change  SAPEventMapPart.txt to  sapEventMapPart.txt
sub changeSAPEventMapPart() 
{
   print "\nChange  SAPEventMapPart.txt to sapEventMapPart.txt...\n";
   my ($aribaBuyerInstallDir, $waabInstallDir) = @_;

   #rename the file in <Ariba Install dir>\CoreServer\channels\MQSeries\
   $fileInAribaMQSeriesDirOld =  $aribaBuyerInstallDir . "/channels/MQSeries/SAPEventMapPart.txt";
   $fileInAribaMQSeriesDirNew =  $aribaBuyerInstallDir . "/channels/MQSeries/sapEventMapPart.txt";
   if (-f $fileInAribaMQSeriesDirOld)
   {
      rename($fileInAribaMQSeriesDirOld, $fileInAribaMQSeriesDirNew);
      print "\nChange  $fileInAribaMQSeriesDirOld to $fileInAribaMQSeriesDirNew. \n";
      logfile ($logFileName, "Change  $fileInAribaMQSeriesDirOld to $fileInAribaMQSeriesDirNew");
   }

   #rename the file in <WAAB Install dir>\samples\aribaBuyer\mapping_names
   $fileInWaabMappingNamesOld =  $waabInstallDir . "/samples/aribaBuyer/mapping_names/SAPEventMapPart.txt";
   $fileInWaabMappingNamesNew =  $waabInstallDir . "/samples/aribaBuyer/mapping_names/sapEventMapPart.txt";
   if (-f $fileInWaabMappingNamesOld)
   {
      rename($fileInWaabMappingNamesOld, $fileInWaabMappingNamesNew);
      print "\nChange  $fileInWaabMappingNamesOld to $fileInWaabMappingNamesNew. \n";
      logfile ($logFileName, "Change  $fileInWaabMappingNamesOld to $fileInWaabMappingNamesNew");
   }

   #rename the file in <WAAB Install dir>\samples\aribaBuyer\mapping_positions
   $fileInWaabMappingPositionOld =  $waabInstallDir . "/samples/aribaBuyer/mapping_positions/SAPEventMapPart.txt";
   $fileInWaabMappingPositionNew =  $waabInstallDir . "/samples/aribaBuyer/mapping_positions/sapEventMapPart.txt";
   if (-f $fileInWaabMappingPositionOld)
   {
      rename($fileInWaabMappingPositionOld, $fileInWaabMappingPositionNew);
      print "\nChange  $fileInWaabMappingPositionOld to $fileInWaabMappingPositionNew. \n";
      logfile ($logFileName, "Change  $fileInWaabMappingPositionOld to $fileInWaabMappingPositionNew");
   }

}

#15 Generates new mapping files
sub generateNewMappingFiles () 
{
   #Generates new mapping files
   print "\nGenerates new mapping files...\n";
   my ($aribaBuyerInstallDir, $efixDir) = @_;
   chdir ($aribaBuyerInstallDir);
   Ariba::Util::safeSystem("runperl ./channels/MQSeries/config.pl -mapping");

   chdir ($efixDir);
   print "\nRun 'runperl ./channels/MQSeries/config.pl -mapping'\n";
   logfile ($logFileName, "Run 'runperl ./channels/MQSeries/config.pl -mapping'");

}

#16 Copy versionMessages.properties 
sub copyVersionMessage () 
{
   #Copy versionMessage.properties file
   print "\nCopy versionMessage.properties...\n";
   my ($efixDir, $waabInstallDir) = @_;

   $efixVersionFile =  $efixDir .         "/bin/com/ibm/bpac/aribabuyer/VersionMessage.properties";
   $waabVersionFile =  $waabInstallDir .  "/bin/com/ibm/bpac/aribabuyer/VersionMessage.properties";
   Ariba::Util::safeCopy($efixVersionFile, $waabVersionFile);
   print "\nCopy $efixVersionFile to $waabVersionFile.\n";
   logfile ($logFileName, "copy $efixVersionFile to $waabVersionFile.");

}


main();


